@@ -7,36 +7,7 @@ from DvG_debug_functions import dprint, tprint, ANSI
 # Show extra debug info in terminal?
 DEBUG = True
 
-"""
-DAQ_trigger.INTERNAL_TIMER
-    I/O device slaved to an external timer originating from Worker_DAQ
-
-DAQ_trigger.SINGLE_SHOT_WAKE_UP
-    Typical use case: Multiple I/O devices that are slaved to a common single
-    external timer originating from a higher scope Python module than 
-    this 'DvG_QdeviceIO' module.
-    See Keysight_N8700_PSU for an example.
-    
-    def simultaneously_trigger_update_multiple_devices():
-        for qdevio in qdevios:
-            qdevio.wake_up()
-            
-    timer_qdevios = QtCore.QTimer()
-    timer_qdevios.timeout.connect(simultaneously_trigger_update_multiple_devices)
-    timer_qdevios.start(UPDATE_INTERVAL_MS)
-
-DAQ_trigger.CONTINUOUS
-    Typical use case: I/O device acting as a master and outputting a continuous
-    stream of data. The worker_DAQ will start up in suspended mode (idling).
-    This allows for a start command to be send to the I/O device, for instance,
-    over a Worker_Send instance. Once the start command has been received and
-    processed by the device, such that it will output a continuous stream of
-    data, worker_DAQ can be taken out of suspended mode and have it listen and
-    receive this data stream.
-    
-"""
-
-global cnt_DAQ_updated, cnt_send_updated, cnt_DAQ_paused
+global cnt_DAQ_updated, cnt_jobs_updated, cnt_DAQ_paused
 
 
 @QtCore.pyqtSlot()
@@ -56,18 +27,16 @@ def process_DAQ_paused():
 
 
 @QtCore.pyqtSlot()
-def process_send_updated():
+def process_jobs_updated():
     # In production code, your GUI update routine would go here
-    tprint("---> received: send_updated")
-    global cnt_send_updated
-    cnt_send_updated += 1
+    tprint("---> received: jobs_updated")
+    global cnt_jobs_updated
+    cnt_jobs_updated += 1
 
 
 class FakeDevice:
     def __init__(self, start_alive=True):
-        # Required members
         self.name = "FakeDev"
-        self.mutex = QtCore.QMutex()
         self.is_alive = start_alive
 
         # Member for testing
@@ -106,10 +75,10 @@ def create_QApplication():
     # app = QtWidgets.QApplication(sys.argv)
     app = QtCore.QCoreApplication(sys.argv)  # Use QCoreApplication instead
 
-    global cnt_DAQ_updated, cnt_DAQ_paused, cnt_send_updated
+    global cnt_DAQ_updated, cnt_DAQ_paused, cnt_jobs_updated
     cnt_DAQ_updated = 0
     cnt_DAQ_paused = 0
-    cnt_send_updated = 0
+    cnt_jobs_updated = 0
 
     return app
 
@@ -139,19 +108,18 @@ def test_Worker_DAQ___INTERNAL_TIMER(start_alive=True):
 
     app = create_QApplication()
     dev = FakeDevice(start_alive=start_alive)
-    qdevio = QDeviceIO(dev)
+    qdev = QDeviceIO(dev)
     # fmt: off
-    qdevio.create_worker_DAQ(
+    qdev.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
         DAQ_function               = DAQ_function,
         DAQ_interval_ms            = 100,
-        DAQ_timer_type             = QtCore.Qt.PreciseTimer,
         critical_not_alive_count   = 10,
         calc_DAQ_rate_every_N_iter = 5,
-        DEBUG                      = DEBUG)
+        debug                      = DEBUG)
     # fmt: on
-    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
-    assert qdevio.start() == start_alive
+    qdev.signal_DAQ_updated.connect(process_DAQ_updated)
+    assert qdev.start() == start_alive
 
     # Simulate device runtime
     start_time = time.perf_counter()
@@ -163,7 +131,7 @@ def test_Worker_DAQ___INTERNAL_TIMER(start_alive=True):
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
     if start_alive:
@@ -191,32 +159,32 @@ def test_Worker_DAQ___SINGLE_SHOT_WAKE_UP(start_alive=True):
 
     app = create_QApplication()
     dev = FakeDevice(start_alive=start_alive)
-    qdevio = QDeviceIO(dev)
+    qdev = QDeviceIO(dev)
     # fmt: off
-    qdevio.create_worker_DAQ(
+    qdev.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.SINGLE_SHOT_WAKE_UP,
         DAQ_function               = DAQ_function,
         critical_not_alive_count   = 1,
         calc_DAQ_rate_every_N_iter = 5,
-        DEBUG                      = DEBUG)
+        debug                      = DEBUG)
     # fmt: on
-    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
-    assert qdevio.start() == start_alive
+    qdev.signal_DAQ_updated.connect(process_DAQ_updated)
+    assert qdev.start() == start_alive
 
     # Immediately fire a call to test if the worker is ready for it
-    qdevio.wake_up_DAQ()
+    qdev.wake_up_DAQ()
 
     # Simulate device runtime
     start_time = time.perf_counter()
-    QtCore.QTimer.singleShot(300, lambda: qdevio.wake_up_DAQ())
-    QtCore.QTimer.singleShot(600, lambda: qdevio.wake_up_DAQ())
+    QtCore.QTimer.singleShot(300, lambda: qdev.wake_up_DAQ())
+    QtCore.QTimer.singleShot(600, lambda: qdev.wake_up_DAQ())
     while time.perf_counter() - start_time < 1:
         app.processEvents()
         time.sleep(0.001)  # Do not hog the CPU
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
     if start_alive:
@@ -242,29 +210,29 @@ def test_Worker_DAQ___CONTINUOUS(start_alive=True):
 
     app = create_QApplication()
     dev = FakeDevice(start_alive=start_alive)
-    qdevio = QDeviceIO(dev)
+    qdev = QDeviceIO(dev)
     # fmt: off
-    qdevio.create_worker_DAQ(
+    qdev.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.CONTINUOUS,
         DAQ_function               = DAQ_function,
         critical_not_alive_count   = 1,
         calc_DAQ_rate_every_N_iter = 5,
-        DEBUG                      = DEBUG,
+        debug                      = DEBUG,
     )
     # fmt: on
-    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
-    qdevio.signal_DAQ_paused.connect(process_DAQ_paused)
-    assert qdevio.start() == start_alive
+    qdev.signal_DAQ_updated.connect(process_DAQ_updated)
+    qdev.signal_DAQ_paused.connect(process_DAQ_paused)
+    assert qdev.start() == start_alive
 
     # Immediately fire a call to test if the worker is ready for it
-    qdevio.unpause_DAQ()
+    qdev.unpause_DAQ()
 
     # Simulate device runtime
     start_time = time.perf_counter()
-    QtCore.QTimer.singleShot(300, lambda: qdevio.pause_DAQ())
-    QtCore.QTimer.singleShot(600, lambda: qdevio.unpause_DAQ())
-    QtCore.QTimer.singleShot(900, lambda: qdevio.pause_DAQ())
-    QtCore.QTimer.singleShot(1200, lambda: qdevio.unpause_DAQ())
+    QtCore.QTimer.singleShot(300, lambda: qdev.pause_DAQ())
+    QtCore.QTimer.singleShot(600, lambda: qdev.unpause_DAQ())
+    QtCore.QTimer.singleShot(900, lambda: qdev.pause_DAQ())
+    QtCore.QTimer.singleShot(1200, lambda: qdev.unpause_DAQ())
     while time.perf_counter() - start_time < 1.6:
         app.processEvents()
         if dev.count_commands == 12:
@@ -273,7 +241,7 @@ def test_Worker_DAQ___CONTINUOUS(start_alive=True):
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
     if start_alive:
@@ -289,29 +257,29 @@ def test_Worker_DAQ___CONTINUOUS__start_dead():
     test_Worker_DAQ___CONTINUOUS(start_alive=False)
 
 
-def test_Worker_send(start_alive=True):
-    print_title("Worker_send" + ("" if start_alive else " - start dead"))
+def test_Worker_jobs(start_alive=True):
+    print_title("Worker_jobs" + ("" if start_alive else " - start dead"))
 
     app = create_QApplication()
     dev = FakeDevice(start_alive=start_alive)
-    qdevio = QDeviceIO(dev)
-    qdevio.create_worker_send(DEBUG=DEBUG)
-    qdevio.signal_send_updated.connect(process_send_updated)
-    assert qdevio.start() == start_alive
+    qdev = QDeviceIO(dev)
+    qdev.create_worker_jobs(debug=DEBUG)
+    qdev.signal_jobs_updated.connect(process_jobs_updated)
+    assert qdev.start() == start_alive
 
     # Immediately fire a call to test if the worker is ready for it
-    qdevio.add_to_send_queue(dev.fake_query_2)
+    qdev.add_to_jobs_queue(dev.fake_query_2)
 
     # fmt: off
     # Simulate device runtime
     start_time = time.perf_counter()
-    QtCore.QTimer.singleShot(100, lambda: qdevio.process_send_queue())
-    QtCore.QTimer.singleShot(200, lambda: qdevio.send(dev.fake_query_2))
-    QtCore.QTimer.singleShot(300, lambda: qdevio.add_to_send_queue(dev.fake_command_with_argument, 0))
-    QtCore.QTimer.singleShot(400, lambda: qdevio.add_to_send_queue(dev.fake_command_with_argument, 0))
-    QtCore.QTimer.singleShot(500, lambda: qdevio.add_to_send_queue(dev.fake_command_with_argument, 0))
-    QtCore.QTimer.singleShot(600, lambda: qdevio.process_send_queue())
-    QtCore.QTimer.singleShot(700, lambda: qdevio.send("trigger_illegal_function_call_error"))
+    QtCore.QTimer.singleShot(100, lambda: qdev.process_jobs_queue())
+    QtCore.QTimer.singleShot(200, lambda: qdev.send(dev.fake_query_2))
+    QtCore.QTimer.singleShot(300, lambda: qdev.add_to_jobs_queue(dev.fake_command_with_argument, 0))
+    QtCore.QTimer.singleShot(400, lambda: qdev.add_to_jobs_queue(dev.fake_command_with_argument, 0))
+    QtCore.QTimer.singleShot(500, lambda: qdev.add_to_jobs_queue(dev.fake_command_with_argument, 0))
+    QtCore.QTimer.singleShot(600, lambda: qdev.process_jobs_queue())
+    QtCore.QTimer.singleShot(700, lambda: qdev.send("trigger_illegal_function_call_error"))
     # fmt: on
     while time.perf_counter() - start_time < 1:
         app.processEvents()
@@ -319,21 +287,21 @@ def test_Worker_send(start_alive=True):
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
     if start_alive:
         assert dev.count_commands == 5
         assert dev.count_replies == 2
-        assert cnt_send_updated == 4
+        assert cnt_jobs_updated == 4
 
 
-def test_Worker_send__start_dead():
-    test_Worker_send(start_alive=False)
+def test_Worker_jobs__start_dead():
+    test_Worker_jobs(start_alive=False)
 
 
-def test_Worker_send__jobs_function():
-    print_title("Worker_send - jobs_function")
+def test_Worker_jobs__jobs_function():
+    print_title("Worker_jobs - jobs_function")
 
     def jobs_function(func, args):
         if func == "special command":
@@ -346,21 +314,21 @@ def test_Worker_send__jobs_function():
 
     app = create_QApplication()
     dev = FakeDevice()
-    qdevio = QDeviceIO(dev)
-    qdevio.create_worker_send(
-        jobs_function=jobs_function, DEBUG=DEBUG,
+    qdev = QDeviceIO(dev)
+    qdev.create_worker_jobs(
+        jobs_function=jobs_function, debug=DEBUG,
     )
-    qdevio.signal_send_updated.connect(process_send_updated)
-    assert qdevio.start() == True
+    qdev.signal_jobs_updated.connect(process_jobs_updated)
+    assert qdev.start() == True
 
     # Immediately fire a call to test if the worker is ready for it
-    qdevio.send(dev.fake_query_2)
+    qdev.send(dev.fake_query_2)
 
     # fmt: off
     # Simulate device runtime
     start_time = time.perf_counter()
-    QtCore.QTimer.singleShot(100, lambda: qdevio.send("special command"))
-    QtCore.QTimer.singleShot(200, lambda: qdevio.send(dev.fake_command_with_argument, 0))
+    QtCore.QTimer.singleShot(100, lambda: qdev.send("special command"))
+    QtCore.QTimer.singleShot(200, lambda: qdev.send(dev.fake_command_with_argument, 0))
     # fmt: on
     while time.perf_counter() - start_time < 0.5:
         app.processEvents()
@@ -368,22 +336,22 @@ def test_Worker_send__jobs_function():
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
     assert dev.count_commands == 3
     assert dev.count_replies == 2
-    assert cnt_send_updated == 3
+    assert cnt_jobs_updated == 3
 
 
 def test_attach_device_twice():
     print_title("Attach device twice")
     import pytest
 
-    qdevio = QDeviceIO(FakeDevice())
+    qdev = QDeviceIO(FakeDevice())
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
-        qdevio.attach_device(FakeDevice())
+        qdev.attach_device(FakeDevice())
     assert pytest_wrapped_e.type == SystemExit
     dprint("Exit code: %i" % pytest_wrapped_e.value.code)
     assert pytest_wrapped_e.value.code == 22
@@ -393,23 +361,23 @@ def test_Worker_DAQ___no_device_attached():
     print_title("Worker_DAQ - no device attached")
     import pytest
 
-    qdevio = QDeviceIO()
+    qdev = QDeviceIO()
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
-        qdevio.create_worker_DAQ()
+        qdev.create_worker_DAQ()
     assert pytest_wrapped_e.type == SystemExit
     dprint("Exit code: %i" % pytest_wrapped_e.value.code)
     assert pytest_wrapped_e.value.code == 99
 
 
-def test_Worker_send__no_device_attached():
-    print_title("Worker_send - no device attached")
+def test_Worker_jobs__no_device_attached():
+    print_title("Worker_jobs - no device attached")
     import pytest
 
-    qdevio = QDeviceIO()
+    qdev = QDeviceIO()
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
-        qdevio.create_worker_send()
+        qdev.create_worker_jobs()
     assert pytest_wrapped_e.type == SystemExit
     dprint("Exit code: %i" % pytest_wrapped_e.value.code)
     assert pytest_wrapped_e.value.code == 99
@@ -419,23 +387,23 @@ def test_Worker_DAQ___start_without_create():
     print_title("Worker_DAQ - start without create")
     import pytest
 
-    qdevio = QDeviceIO(FakeDevice())
+    qdev = QDeviceIO(FakeDevice())
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
-        qdevio.start_worker_DAQ()
+        qdev.start_worker_DAQ()
     assert pytest_wrapped_e.type == SystemExit
     dprint("Exit code: %i" % pytest_wrapped_e.value.code)
     assert pytest_wrapped_e.value.code == 404
 
 
-def test_Worker_send__start_without_create():
-    print_title("Worker_send - start without create")
+def test_Worker_jobs__start_without_create():
+    print_title("Worker_jobs - start without create")
     import pytest
 
-    qdevio = QDeviceIO(FakeDevice())
+    qdev = QDeviceIO(FakeDevice())
 
     with pytest.raises(SystemExit) as pytest_wrapped_e:
-        qdevio.start_worker_send()
+        qdev.start_worker_jobs()
     assert pytest_wrapped_e.type == SystemExit
     dprint("Exit code: %i" % pytest_wrapped_e.value.code)
     assert pytest_wrapped_e.value.code == 404
@@ -445,25 +413,25 @@ def test_Worker_DAQ___quit_without_start():
     print_title("Worker_DAQ - quit without start")
 
     app = create_QApplication()
-    qdevio = QDeviceIO(FakeDevice())
-    qdevio.create_worker_DAQ()
+    qdev = QDeviceIO(FakeDevice())
+    qdev.create_worker_DAQ()
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
 
-def test_Worker_send__quit_without_start():
-    print_title("Worker_send - quit without start")
+def test_Worker_jobs__quit_without_start():
+    print_title("Worker_jobs - quit without start")
 
     app = create_QApplication()
-    qdevio = QDeviceIO(FakeDevice())
-    qdevio.create_worker_send()
+    qdev = QDeviceIO(FakeDevice())
+    qdev.create_worker_jobs()
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
 
@@ -473,23 +441,22 @@ def test_Worker_DAQ___rate():
     def DAQ_function():
         # Must return True when successful, False otherwise
         reply = dev.fake_query_1()
-        dprint(" " * 50 + "%.1f Hz" % qdevio.obtained_DAQ_rate_Hz)
+        dprint(" " * 50 + "%.1f Hz" % qdev.obtained_DAQ_rate_Hz)
         return reply[-4:] == "0101"
 
     app = create_QApplication()
     dev = FakeDevice()
-    qdevio = QDeviceIO(dev)
+    qdev = QDeviceIO(dev)
     # fmt: off
-    qdevio.create_worker_DAQ(
+    qdev.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
         DAQ_function               = DAQ_function,
         DAQ_interval_ms            = 10,
-        DAQ_timer_type             = QtCore.Qt.PreciseTimer,
         critical_not_alive_count   = 1,
         calc_DAQ_rate_every_N_iter = 20,
-        DEBUG                      = DEBUG)
+        debug                      = DEBUG)
     # fmt: on
-    assert qdevio.start() == True
+    assert qdev.start() == True
 
     # Simulate device runtime
     start_time = time.perf_counter()
@@ -499,16 +466,11 @@ def test_Worker_DAQ___rate():
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
-    assert (
-        qdevio.obtained_DAQ_interval_ms >= 9
-        and qdevio.obtained_DAQ_interval_ms <= 11
-    )
-    assert (
-        qdevio.obtained_DAQ_rate_Hz >= 99 and qdevio.obtained_DAQ_rate_Hz <= 101
-    )
+    assert 9 <= qdev.obtained_DAQ_interval_ms <= 11
+    assert 99 <= qdev.obtained_DAQ_rate_Hz <= 101
 
 
 def test_Worker_DAQ___lose_connection():
@@ -516,7 +478,7 @@ def test_Worker_DAQ___lose_connection():
 
     def DAQ_function():
         # Must return True when successful, False otherwise
-        if qdevio.update_counter_DAQ == 10:
+        if qdev.update_counter_DAQ == 10:
             dev.is_alive = False
 
         reply = dev.fake_query_1()
@@ -536,19 +498,23 @@ def test_Worker_DAQ___lose_connection():
 
     app = create_QApplication()
     dev = FakeDevice()
-    qdevio = QDeviceIO(dev)
+
+    # Forcefully remove members as extra test
+    del dev.name
+    del dev.is_alive
+
+    qdev = QDeviceIO(dev)
     # fmt: off
-    qdevio.create_worker_DAQ(
+    qdev.create_worker_DAQ(
         DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
         DAQ_function               = DAQ_function,
         DAQ_interval_ms            = 20,
-        DAQ_timer_type             = QtCore.Qt.PreciseTimer,
         critical_not_alive_count   = 3,
         calc_DAQ_rate_every_N_iter = 20,
-        DEBUG                      = DEBUG)
+        debug                      = DEBUG)
     # fmt: on
-    qdevio.signal_connection_lost.connect(process_connection_lost)
-    assert qdevio.start() == True
+    qdev.signal_connection_lost.connect(process_connection_lost)
+    assert qdev.start() == True
 
     # Simulate device runtime
     while go:
@@ -557,13 +523,13 @@ def test_Worker_DAQ___lose_connection():
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
 
 class QDeviceIO_subclassed(QDeviceIO, QtCore.QObject):
     def __init__(
-        self, dev=None, DAQ_function=None, DEBUG=False, parent=None,
+        self, dev=None, DAQ_function=None, debug=False, parent=None,
     ):
         super(QDeviceIO_subclassed, self).__init__(parent=parent)
 
@@ -574,13 +540,12 @@ class QDeviceIO_subclassed(QDeviceIO, QtCore.QObject):
             DAQ_trigger                = DAQ_trigger.INTERNAL_TIMER,
             DAQ_function               = DAQ_function,
             DAQ_interval_ms            = 100,
-            DAQ_timer_type             = QtCore.Qt.PreciseTimer,
             critical_not_alive_count   = 10,
             calc_DAQ_rate_every_N_iter = 5,
-            DEBUG                      = DEBUG,
+            debug                      = DEBUG,
         )
         # fmt: on
-        self.create_worker_send(DEBUG=DEBUG)
+        self.create_worker_jobs(debug=DEBUG)
 
 
 def test_Worker_DAQ___INTERNAL_TIMER__mixin_class():
@@ -593,18 +558,18 @@ def test_Worker_DAQ___INTERNAL_TIMER__mixin_class():
 
     app = create_QApplication()
     dev = FakeDevice()
-    qdevio = QDeviceIO_subclassed(
-        dev=dev, DAQ_function=DAQ_function, DEBUG=DEBUG,
+    qdev = QDeviceIO_subclassed(
+        dev=dev, DAQ_function=DAQ_function, debug=DEBUG,
     )
-    qdevio.signal_DAQ_updated.connect(process_DAQ_updated)
-    qdevio.signal_send_updated.connect(process_send_updated)
-    qdevio.start()
+    qdev.signal_DAQ_updated.connect(process_DAQ_updated)
+    qdev.signal_jobs_updated.connect(process_jobs_updated)
+    qdev.start()
 
     # fmt: off
     # Simulate device runtime
     start_time = time.perf_counter()
-    QtCore.QTimer.singleShot(300, lambda: qdevio.send(dev.fake_query_2))
-    QtCore.QTimer.singleShot(600, lambda: qdevio.send(dev.fake_command_with_argument, 0))
+    QtCore.QTimer.singleShot(300, lambda: qdev.send(dev.fake_query_2))
+    QtCore.QTimer.singleShot(600, lambda: qdev.send(dev.fake_command_with_argument, 0))
     # fmt: on
     while time.perf_counter() - start_time < 1:
         app.processEvents()
@@ -612,7 +577,7 @@ def test_Worker_DAQ___INTERNAL_TIMER__mixin_class():
 
     tprint("About to quit")
     app.processEvents()
-    assert qdevio.quit() == True
+    assert qdev.quit() == True
     app.quit()
 
     assert dev.count_commands >= 11
@@ -620,7 +585,7 @@ def test_Worker_DAQ___INTERNAL_TIMER__mixin_class():
     assert (
         cnt_DAQ_updated >= 9
     )  # Last signal is not always received before thread is quit
-    assert cnt_send_updated == 2
+    assert cnt_jobs_updated == 2
 
 
 # ------------------------------------------------------------------------------
@@ -636,16 +601,16 @@ if __name__ == "__main__":
         test_Worker_DAQ___SINGLE_SHOT_WAKE_UP__start_dead()
         test_Worker_DAQ___CONTINUOUS()
         test_Worker_DAQ___CONTINUOUS__start_dead()
-        test_Worker_send()
-        test_Worker_send__start_dead()
-        test_Worker_send__jobs_function()
+        test_Worker_jobs()
+        test_Worker_jobs__start_dead()
+        test_Worker_jobs__jobs_function()
         test_attach_device_twice()
         test_Worker_DAQ___no_device_attached()
-        test_Worker_send__no_device_attached()
+        test_Worker_jobs__no_device_attached()
         test_Worker_DAQ___start_without_create()
-        test_Worker_send__start_without_create()
+        test_Worker_jobs__start_without_create()
         test_Worker_DAQ___quit_without_start()
-        test_Worker_send__quit_without_start()
+        test_Worker_jobs__quit_without_start()
         test_Worker_DAQ___rate()
         test_Worker_DAQ___lose_connection()
         test_Worker_DAQ___INTERNAL_TIMER__mixin_class()
@@ -666,20 +631,21 @@ if __name__ == "__main__":
         # test_Worker_DAQ___CONTINUOUS()
         # test_Worker_DAQ___CONTINUOUS__start_dead()
 
-        test_Worker_DAQ___rate()
+        # test_Worker_DAQ___rate()
         # test_Worker_DAQ___lose_connection()
         # test_Worker_DAQ___no_device_attached()
         # test_Worker_DAQ___start_without_create()
 
-        # test_Worker_send()
-        # test_Worker_send__start_dead()
-        # test_Worker_send__jobs_function()
-        # test_Worker_send__no_device_attached()
-        # test_Worker_send__start_without_create()
+        # test_Worker_jobs()
+        # test_Worker_jobs__start_dead()
+        # test_Worker_jobs__jobs_function()
+        # test_Worker_jobs__no_device_attached()
+        # test_Worker_jobs__start_without_create()
 
         # test_Worker_DAQ___quit_without_start()
-        # test_Worker_send__quit_without_start()
+        # test_Worker_jobs__quit_without_start()
 
         # test_attach_device_twice()
 
         # test_Worker_DAQ___INTERNAL_TIMER__mixin_class()
+        test_Worker_DAQ___lose_connection()
